==> eslint-config-dollarshaveclub-6.1.0.tgz: package/eslint-plugin-import-dollarshaveclub.js <==
module.exports = {
  rules: {
    'import/default': 'off',
    'import/no-absolute-path': 'error',
    'import/no-dynamic-require': 'error',
    'import/no-useless-path-segments': [
      'error',
      {
        noUselessIndex: true,
      },
    ],
    'import/export': 'error',
    'import/no-named-as-default': 'error',
    'import/no-named-as-default-member': 'warn',
    'import/no-deprecated': 'warn',
    'import/no-extraneous-dependencies': [
      'error',
      {
        devDependencies: [
          '**/__mocks__/**',
          '**/__tests__/**',
          '**/{.,}storybook/**',
          '**/*.test.*',
          '**/config/**',
          '**/prettier.config.*',
          '**/scripts/**',
          '**/stories/**',
          '**/tests/**',
          '**/testing/**',
          '**/prettier.config.js',
        ],
      },
    ],
    'import/no-mutable-exports': 'warn',
    'no-restricted-imports': [
      'error',
      {
        paths: [
          {
            name: '@dollarshaveclub/types/fixtures',
            message: 'Fixtures are not allowed outside of test environments.',
          },
        ],
        patterns: ['@dollarshaveclub/*/src/*'],
      },
    ],
    'import/first': 'error',
    'import/newline-after-import': 'warn',
    'import/prefer-default-export': 'off',
    'import/order': 'off',
  },
  overrides: [
    {
      files: ['**/*.test.ts', '**/*.test.tsx', '**/__{mocks,tests}__/**'],
      rules: {
        'no-restricted-imports': [
          'error',
          {
            patterns: ['@dollarshaveclub/*/src/*'],
          },
        ],
      },
    },
  ],
}

==> eslint-config-dollarshaveclub-8.0.1.tgz: package/eslint-plugin-import-dollarshaveclub.js <==
const devDependencies = [
  '**/__fixtures__/**',
  '**/__mocks__/**',
  '**/__tests__/**',
  '**/{.,}storybook/**',
  '**/*.config.*',
  '**/*.test.*',
  '**/config/**',
  '**/Gulpfile.*',
  '**/scripts/**',
  '**/stories/**',
  '**/testing/**',
  '**/tests/**',
  '**/test**',
]

module.exports = {
  rules: {
    'import/default': 'off',
    'import/no-absolute-path': 'error',
    'import/no-dynamic-require': 'error',
    'import/no-useless-path-segments': [
      'error',
      {
        noUselessIndex: true,
      },
    ],
    'import/export': 'error',
    'import/no-named-as-default': 'error',
    'import/no-named-as-default-member': 'warn',
    'import/no-deprecated': 'warn',
    'import/no-extraneous-dependencies': [
      'error',
      {
        devDependencies: [...devDependencies],
      },
    ],
    'import/no-mutable-exports': 'warn',
    'no-restricted-imports': [
      'error',
      {
        paths: [
          {
            name: '@dollarshaveclub/types/fixtures',
            message: 'Fixtures are not allowed outside of test environments.',
          },
        ],
        patterns: ['@dollarshaveclub/*/build/*', '@dollarshaveclub/*/dist/*'],
      },
    ],
    'import/first': 'error',
    'import/newline-after-import': 'warn',
    'import/prefer-default-export': 'off',
    'import/order': 'off',
  },
  overrides: [
    {
      files: [...devDependencies],
      rules: {
        'no-restricted-imports': [
          'error',
          {
            patterns: [
              '@dollarshaveclub/*/build/*',
              '@dollarshaveclub/*/dist/*',
            ],
          },
        ],
      },
    },
  ],
}
